@@ -360,7 +360,7 @@ class healthBar():
 #         self.level = level
 
 
-ws = initialize("/python_questions.xlsx")
+ws = initialize("PythonPals/python_questions.xlsx")
 screen = pygame.display.set_mode((0, 0), pygame.RESIZABLE)
 white = (255, 255, 255)
 purple = (110, 113, 198)
